@@ -218,6 +218,13 @@ class SocketService(MultiProcService):
         raise NotImplementedError
 
     def run(self, io_loop=None):
+        """
+        must after super run::
+        
+            from tornado.ioloop import IOLoop
+            IOLoop.instance().start()
+        
+        """
         MultiProcService.run(self)
 
         self.init_sockets()
@@ -226,9 +233,6 @@ class SocketService(MultiProcService):
         self.socket_server.start(num_processes=self.config["num_processes"])
         self.socket_server.add_sockets(self.sockets)
 
-        from tornado.ioloop import IOLoop
-        IOLoop.instance().start()
-
     def stop(self):
         from tornado.ioloop import IOLoop
 
@@ -271,43 +275,3 @@ class Error(Exception):
     def get_message(self):
         return self.message
 
-
-def class_name_to_class(class_name):
-    """
-    convert ``'someproject.somens.Foor'`` to ``someproject.somens.Foor``
-    """
-    _class = class_name.split(".")
-
-    class_module = ".".join(_class[:-1])
-    class_module = importlib.import_module(class_module)
-
-    _class = getattr(class_module, _class[-1])
-
-    return _class
-
-
-def class_names_to_classes(class_names):
-    """
-    convert
-    
-    ::
-        [
-            'someproject.somens.Foor',
-            'otherproject.somens.Bar'
-        ]
-    
-    to
-    
-    ::
-        [
-            someproject.somens.Foor,
-            otherproject.somens.Bar
-        ]
-    
-    """
-    classes = []
-    for class_name in class_names:
-        _class = class_name_to_class(class_name)
-        classes.append(_class)
-
-    return classes
